==> kea-docs-2.0.2-1-armv7h.pkg.tar.xz: usr/share/doc/kea/devel/dc/d17/config__messages_8cc.js <==
var config__messages_8cc =
[
    [ "COMMAND_ACCEPTOR_START", "dc/d17/config__messages_8cc.html#a8264116d2fb44c47b27d49c1937f8330", null ],
    [ "COMMAND_DEREGISTERED", "dc/d17/config__messages_8cc.html#a58804a1483456f6adbea40afe2834625", null ],
    [ "COMMAND_EXTENDED_REGISTERED", "dc/d17/config__messages_8cc.html#a0e6e723b108cd218663faa926d8671e5", null ],
    [ "COMMAND_HTTP_LISTENER_STARTED", "dc/d17/config__messages_8cc.html#a39e9c3736d770a3f16dd3f4261351c0e", null ],
    [ "COMMAND_HTTP_LISTENER_STOPPED", "dc/d17/config__messages_8cc.html#a86287b9b82383539ee22377908de091d", null ],
    [ "COMMAND_HTTP_LISTENER_STOPPING", "dc/d17/config__messages_8cc.html#ab53159c43021741d078cafff14401ffc", null ],
    [ "COMMAND_PROCESS_ERROR1", "dc/d17/config__messages_8cc.html#a055b479551f919f07445cc94b3f05dc5", null ],
    [ "COMMAND_PROCESS_ERROR2", "dc/d17/config__messages_8cc.html#a9af5d06ec1b157500a7ac830a9ce7668", null ],
    [ "COMMAND_RECEIVED", "dc/d17/config__messages_8cc.html#a777eeda4b94459eaff6d4daf30e71a8b", null ],
    [ "COMMAND_REGISTERED", "dc/d17/config__messages_8cc.html#aac10e2179a15d73be8ca9f69f2ee07c2", null ],
    [ "COMMAND_RESPONSE_ERROR", "dc/d17/config__messages_8cc.html#a96846091df5a0385125ab529be9b1e84", null ],
    [ "COMMAND_SOCKET_ACCEPT_FAIL", "dc/d17/config__messages_8cc.html#ab8460e190017980d0e296b7057b24d4c", null ],
    [ "COMMAND_SOCKET_CLOSED_BY_FOREIGN_HOST", "dc/d17/config__messages_8cc.html#a62a9a29403f612db0222fe64580d9e73", null ],
    [ "COMMAND_SOCKET_CONNECTION_CANCEL_FAIL", "dc/d17/config__messages_8cc.html#a402be5f8a498fa8016ed3955c1cc3f0e", null ],
    [ "COMMAND_SOCKET_CONNECTION_CLOSE_FAIL", "dc/d17/config__messages_8cc.html#ac989bad6946427b67525257973284582", null ],
    [ "COMMAND_SOCKET_CONNECTION_CLOSED", "dc/d17/config__messages_8cc.html#a27b4b187c214034d3ed5a1836c42a407", null ],
    [ "COMMAND_SOCKET_CONNECTION_OPENED", "dc/d17/config__messages_8cc.html#a60f22f3b51fc340f149baf5dfcfa60a2", null ],
    [ "COMMAND_SOCKET_CONNECTION_SHUTDOWN_FAIL", "dc/d17/config__messages_8cc.html#a19a9251d25cbfe1b4be7b041e270369b", null ],
    [ "COMMAND_SOCKET_CONNECTION_TIMEOUT", "dc/d17/config__messages_8cc.html#a6ebe8476418064b37b48acc318fae7c4", null ],
    [ "COMMAND_SOCKET_READ", "dc/d17/config__messages_8cc.html#adf6c420f83015d01028a6a59e1a2b5ef", null ],
    [ "COMMAND_SOCKET_READ_FAIL", "dc/d17/config__messages_8cc.html#a0aa2a0924ed06ce3ebb91409e87f01da", null ],
    [ "COMMAND_SOCKET_WRITE", "dc/d17/config__messages_8cc.html#aee33a7db00a840e1beb050c54517b293", null ],
    [ "COMMAND_SOCKET_WRITE_FAIL", "dc/d17/config__messages_8cc.html#ac3e78992e8fafe4fa9ff0ebf473de876", null ],
    [ "COMMAND_WATCH_SOCKET_CLEAR_ERROR", "dc/d17/config__messages_8cc.html#af22d65641b34eb72c823b99cabe92ae3", null ],
    [ "COMMAND_WATCH_SOCKET_CLOSE_ERROR", "dc/d17/config__messages_8cc.html#ad1e0430ed3af711c0f83be19124b863c", null ],
    [ "COMMAND_WATCH_SOCKET_MARK_READY_ERROR", "dc/d17/config__messages_8cc.html#aea8036dbc52316c4a9622047c96499a4", null ]
];

==> kea-docs-2.2.0-2-armv7h.pkg.tar.xz: usr/share/doc/kea/devel/dc/d17/config__messages_8cc.js <==
var config__messages_8cc =
[
    [ "COMMAND_ACCEPTOR_START", "dc/d17/config__messages_8cc.html#a8264116d2fb44c47b27d49c1937f8330", null ],
    [ "COMMAND_DEREGISTERED", "dc/d17/config__messages_8cc.html#a58804a1483456f6adbea40afe2834625", null ],
    [ "COMMAND_EXTENDED_REGISTERED", "dc/d17/config__messages_8cc.html#a0e6e723b108cd218663faa926d8671e5", null ],
    [ "COMMAND_HTTP_LISTENER_COMMAND_REJECTED", "dc/d17/config__messages_8cc.html#a997bcf0ec6eb54fb2a3425a662fd26f6", null ],
    [ "COMMAND_HTTP_LISTENER_STARTED", "dc/d17/config__messages_8cc.html#a39e9c3736d770a3f16dd3f4261351c0e", null ],
    [ "COMMAND_HTTP_LISTENER_STOPPED", "dc/d17/config__messages_8cc.html#a86287b9b82383539ee22377908de091d", null ],
    [ "COMMAND_HTTP_LISTENER_STOPPING", "dc/d17/config__messages_8cc.html#ab53159c43021741d078cafff14401ffc", null ],
    [ "COMMAND_PROCESS_ERROR1", "dc/d17/config__messages_8cc.html#a055b479551f919f07445cc94b3f05dc5", null ],
    [ "COMMAND_PROCESS_ERROR2", "dc/d17/config__messages_8cc.html#a9af5d06ec1b157500a7ac830a9ce7668", null ],
    [ "COMMAND_RECEIVED", "dc/d17/config__messages_8cc.html#a777eeda4b94459eaff6d4daf30e71a8b", null ],
    [ "COMMAND_REGISTERED", "dc/d17/config__messages_8cc.html#aac10e2179a15d73be8ca9f69f2ee07c2", null ],
    [ "COMMAND_RESPONSE_ERROR", "dc/d17/config__messages_8cc.html#a96846091df5a0385125ab529be9b1e84", null ],
    [ "COMMAND_SOCKET_ACCEPT_FAIL", "dc/d17/config__messages_8cc.html#ab8460e190017980d0e296b7057b24d4c", null ],
    [ "COMMAND_SOCKET_CLOSED_BY_FOREIGN_HOST", "dc/d17/config__messages_8cc.html#a62a9a29403f612db0222fe64580d9e73", null ],
    [ "COMMAND_SOCKET_CONNECTION_CANCEL_FAIL", "dc/d17/config__messages_8cc.html#a402be5f8a498fa8016ed3955c1cc3f0e", null ],
    [ "COMMAND_SOCKET_CONNECTION_CLOSE_FAIL", "dc/d17/config__messages_8cc.html#ac989bad6946427b67525257973284582", null ],
    [ "COMMAND_SOCKET_CONNECTION_CLOSED", "dc/d17/config__messages_8cc.html#a27b4b187c214034d3ed5a1836c42a407", null ],
    [ "COMMAND_SOCKET_CONNECTION_OPENED", "dc/d17/config__messages_8cc.html#a60f22f3b51fc340f149baf5dfcfa60a2", null ],
    [ "COMMAND_SOCKET_CONNECTION_SHUTDOWN_FAIL", "dc/d17/config__messages_8cc.html#a19a9251d25cbfe1b4be7b041e270369b", null ],
    [ "COMMAND_SOCKET_CONNECTION_TIMEOUT", "dc/d17/config__messages_8cc.html#a6ebe8476418064b37b48acc318fae7c4", null ],
    [ "COMMAND_SOCKET_READ", "dc/d17/config__messages_8cc.html#adf6c420f83015d01028a6a59e1a2b5ef", null ],
    [ "COMMAND_SOCKET_READ_FAIL", "dc/d17/config__messages_8cc.html#a0aa2a0924ed06ce3ebb91409e87f01da", null ],
    [ "COMMAND_SOCKET_WRITE", "dc/d17/config__messages_8cc.html#aee33a7db00a840e1beb050c54517b293", null ],
    [ "COMMAND_SOCKET_WRITE_FAIL", "dc/d17/config__messages_8cc.html#ac3e78992e8fafe4fa9ff0ebf473de876", null ],
    [ "COMMAND_WATCH_SOCKET_CLEAR_ERROR", "dc/d17/config__messages_8cc.html#af22d65641b34eb72c823b99cabe92ae3", null ],
    [ "COMMAND_WATCH_SOCKET_CLOSE_ERROR", "dc/d17/config__messages_8cc.html#ad1e0430ed3af711c0f83be19124b863c", null ],
    [ "COMMAND_WATCH_SOCKET_MARK_READY_ERROR", "dc/d17/config__messages_8cc.html#aea8036dbc52316c4a9622047c96499a4", null ]
];
